import React from 'react';
import { ImpactEnum, ImpactValueEnum } from '../../constants/impactConstants';
interface ITrendImpactValue {
    value: number;
    unit?: string;
}
declare type TrendImpactsType = Record<ImpactValueEnum, ITrendImpactValue>;
declare type ImpactsType = Record<ImpactValueEnum, number>;
export interface IImpactNumberFormatProps {
    /**
     * Defines impact value to scale up to next possible unit
     * For example: 1000g of impact will be displayed as 1kg and so on
     */
    autoScale?: boolean;
    /**
     * Defines the formatting of the impact value based on the locale (Javscript number.toLocaleString) options
     */
    locale?: string;
    /**
     * Defines the formatting of the impact value to show only few digits and rest zeros
     */
    significantDigits?: number;
    /**
     * Defines whether to format the value based on Javascript number.toLocaleString()
     */
    useLocale?: boolean;
}
export interface IImpactStatsProps extends IImpactNumberFormatProps, Omit<React.ComponentPropsWithoutRef<'div'>, 'onSelect'> {
    /**
     * Defines impact value to scale up to next possible unit
     * For example: 1000g of impact will be displayed as 1kg and so on
     */
    autoScale?: boolean;
    /**
     * Defines to show/hide biodiversity stat
     */
    showBio?: boolean;
    /**
     * Defines the stats data for 4 impacts
     */
    impacts: ImpactsType;
    /**
     * Defines the comparison stats data for 4 impacts
     */
    nextImpacts?: ImpactsType;
    /**
     * Defines the difference of current and next impacts data as Trend
     */
    trend?: TrendImpactsType;
    /**
     * Defines the callback for the selection of the impact stat
     */
    onSelect?: (impactType: ImpactEnum) => void;
    /**
     * Defines the selected appearance of the particular impact stat
     */
    selected?: ImpactEnum;
    /**
     * Defines the formatting of the impact value to show only few digits and rest zeros
     */
    significantDigits?: number;
    /**
     * Defines whether to format the value based on Javascript number.toLocaleString()
     */
    useLocale?: boolean;
    /**
     * Defines rounded corners
     */
    roundedCorners?: boolean;
}
export declare function ImpactStats({ autoScale, className, showBio, impacts, locale, nextImpacts, onSelect, selected, significantDigits, trend, useLocale, roundedCorners, }: IImpactStatsProps): JSX.Element;
export {};
//# sourceMappingURL=ImpactStats.d.ts.map